# tg-react

![https://badge.fury.io/py/tg-react](https://badge.fury.io/py/tg-react.png)
![Workflow status](https://github.com/thorgate/tg-react/actions/workflows/python-package.yml/badge.svg?branch=master)

Helpers for react based applications running on django.

## Documentation

The full documentation is at https://tg-react.readthedocs.org.

## Quickstart

Install tg-react:

```
pip install tg-react
```

Then use it in a project:

```
import tg_react
```

## Features

* TODO

.. TODO: List features and link to documentation for more information

## Changelog

Changes are documented under `Github Releases <https://github.com/thorgate/tg-react/releases>`_.
